@@ -1,6 +1,6 @@
 from gi.repository import *
-from txtr.textview import *
-from txtr.linenumbers import *
+from textview import *
+from linenumbers import *
 
 class Child(Gtk.ScrolledWindow):
 	def __init__(self, handler, content):
