@@ -1,12 +1,11 @@
 from gi.repository import Gtk
-from txtr.handler import *
-from txtr.window import Window
+from window import Window
 
 class Greet(Gtk.Window):
 	def __init__(self):
 		super(Greet, self).__init__()
 		self.set_position(Gtk.WindowPosition.CENTER_ALWAYS)
-		self.set_default_size(500,400)
+		self.set_default_size(400,300)
 		self.set_layout()
 		self.connect('destroy', self.destroy_window)
 		
@@ -22,8 +21,8 @@ class Greet(Gtk.Window):
 		button.set_relief(Gtk.ReliefStyle.NONE)
 		button.set_can_focus(False)
 		button.connect('clicked', self.on_click_open)
-		box.pack_start(label, False, False, 60)
-		box.pack_start(button, False, False, 15)
+		box.pack_start(label, False, True, 50)
+		box.pack_start(button, False, True, 0)
 		self.add(box)
 	
 	def on_click_open(self, data):
@@ -31,17 +30,11 @@ class Greet(Gtk.Window):
 				, Gtk.STOCK_OPEN, Gtk.ResponseType.ACCEPT))
 		d.set_default_response(Gtk.ResponseType.ACCEPT)
 		if d.run() == Gtk.ResponseType.ACCEPT:
-			
-			
-			#self.handler = Handler(window)
 			filename = d.get_filename()
-			window = Window(filename)
 			self.hide()
-			#self.handler.notebook.new_tab(filename)
-			#name = self.handler.split_filename(filename)
-			#self.mw.set_title('Tahrir - ' + name)
-			#doc = self.handler.notebook.get_current_doc()
-			#doc.set_modified(False)
+			window = Window(filename)
+			statusbar = window.handler.statusbar
+			statusbar.push(statusbar.get_context_id('Open Doc'), 'Document has been opened successfuly')
 		d.destroy()
 		
 	def destroy_window(self, data):
