@@ -1,5 +1,5 @@
 from gi.repository import Gtk
-from txtr.handler import *
+from handler import *
 
 class Window(Gtk.Window):
 	def __init__(self, filename):
@@ -16,10 +16,14 @@ class Window(Gtk.Window):
 	def set_layout(self):
 		layout = Gtk.Box() 
 		layout.set_orientation(Gtk.Orientation.VERTICAL)
+		menubar = self.handler.menubar
 		toolbar = self.handler.toolbar
 		notebook = self.handler.notebook
-		layout.pack_start(toolbar, False, False, 0)
+		statusbar = self.handler.statusbar
+		layout.pack_start(menubar, False, True, 0)
+		layout.pack_start(toolbar, False, True, 0)
 		layout.pack_start(notebook, True, True, 0)
+		layout.pack_start(statusbar, False, True, 0)
 		self.add(layout)
 		#notebook.get_current_doc().grab_focus()
 		notebook.new_tab(self.filename)
